@@ -52,7 +52,6 @@ static const char *EXTRA_MONITOR_PATHS[] = { "/system/gnome_vfs",
 static void     global_preferences_install_defaults      (void);
 static void     global_preferences_register_enumerations (void);
 static gpointer default_font_callback                    (void);
-static void     import_old_preferences_if_needed         (void);
 static gpointer default_home_link_name                   (void);
 static gpointer default_computer_link_name               (void);
 static gpointer default_trash_link_name                  (void);
@@ -66,35 +65,6 @@ typedef enum
 	PREFERENCE_STRING_LIST
 } PreferenceType;
 
-
-/* values for tracking the current preferences version so when
-   key names are changed Nautilus can import the old preferences */
-
-#define PREFERENCES_VERSION                    "preferences_version"
-#define PREFERENCES_CURRENT_VERSION            2
-
-typedef struct 
-{
-	const char *new_key;
-	const char *old_key;
-} PreferenceImportType;
-
-/* format is { NEW_KEY, KEY_TO_IMPORT_FROM } */
-static PreferenceImportType OLD_PREFERENCES_TO_IMPORT[] = { 
-	{ NAUTILUS_PREFERENCES_THEME, 
-	  "/apps/nautilus/preferences/theme", 
-	},
-	{ NAUTILUS_PREFERENCES_SHOW_HIDDEN_FILES, 
-	  "/apps/nautilus/preferences/show_hidden_files", 
-	}, 
-	{ NAUTILUS_PREFERENCES_SHOW_BACKUP_FILES, 
-	  "/apps/nautilus/preferences/show_backup_files", 
-	},
-	{ NULL }
-};
-
-
-
 /* Enumerations used to qualify some INTEGER preferences */
 static EelEnumerationEntry speed_tradeoff_enum_entries[] = {
 	{ "always",	    N_("_Always"),		NAUTILUS_SPEED_TRADEOFF_ALWAYS },
@@ -519,6 +489,16 @@ static const PreferenceDefault preference_defaults[] = {
 	  default_trash_link_name, g_free,
 	},
 	
+	{ NAUTILUS_PREFERENCES_DESKTOP_VOLUMES_VISIBLE,
+	  PREFERENCE_BOOLEAN,
+	  GINT_TO_POINTER (TRUE)
+	},
+
+	{ NAUTILUS_PREFERENCES_DESKTOP_NETWORK_VISIBLE,
+	  PREFERENCE_BOOLEAN,
+	  GINT_TO_POINTER (FALSE)
+	},
+	
 	{ NULL }
 };
 
@@ -715,47 +695,6 @@ default_icon_view_sort_order_or_manual_layout_changed_callback (gpointer callbac
 	}
 }
 
-
-static void
-import_old_preferences_if_needed (void)
-{
-	int i;
-	int current_preferences_version;
-	PreferenceImportType *to_import;
-	GConfClient *client;
-	GConfValue *value;
-	GError *error;
-
-	current_preferences_version = eel_preferences_get_integer (PREFERENCES_VERSION);
-
-	if (current_preferences_version == PREFERENCES_CURRENT_VERSION) {
-		return;
-	}
-	
-	eel_preferences_set_integer (PREFERENCES_VERSION, PREFERENCES_CURRENT_VERSION);
-	
-	client = gconf_client_get_default ();
-
-	/* generic updater, works when values have only moved */
-	for (i=0; OLD_PREFERENCES_TO_IMPORT[i].new_key != NULL; i++) {
-		to_import = & (OLD_PREFERENCES_TO_IMPORT[i]);
-
-		if (gconf_client_key_is_writable (client, to_import->new_key, NULL)) {
-			error = NULL;
-			value = gconf_client_get (client, to_import->old_key, &error);
-
-			if ((error == NULL) && (value != NULL)) {
-				gconf_client_set (client, to_import->new_key, value, NULL);
-			} else {
-				if (error != NULL) {
-					g_error_free (error);
-				}
-			}
-		}
-	}
-}
-
-
 void
 nautilus_global_preferences_init (void)
 {
@@ -770,8 +709,6 @@ nautilus_global_preferences_init (void)
 
 	eel_preferences_init ("/apps/nautilus");
 
-	import_old_preferences_if_needed ();
-	
 	/* Install defaults */
 	global_preferences_install_defaults ();
 
